@@ -1,3 +1,5 @@
+from colorama import Style, Fore
+
 class LiveData:
     def __init__(self, symbol):
         self.timestamp = None
@@ -17,6 +19,9 @@ class LiveData:
         self.day_high = None
         self.day_low = None
         self.day_open = None
+        self.starting_formatter = ""
+        self.ending_formatter = ""
+        # For level 2 and level 3 data
         # self.bids = []
         # self.asks = []
 
@@ -40,7 +45,15 @@ class LiveData:
         return res
 
     def __str__(self):
-        return str(self.__dict__)
+        if self.special_tag == "":
+            self.starting_formatter = self.ending_formatter = ""
+        elif self.special_tag != "":
+            if self.special_tag == "H":
+                self.starting_formatter = f"{Style.BRIGHT} {Fore.GREEN}"
+            elif self.special_tag == "":
+                self.starting_formatter = f"{Style.BRIGHT} {Fore.RED}"
+            self.ending_formatter = f"{Style.RESET_ALL}"
+        return f"{self.starting_formatter} {str(self.__dict__)} {self.ending_formatter}"
 
 
 class TouchlineData:
